@@ -22,7 +22,6 @@
 
 using namespace IncidenceEditorNG;
 using namespace Qt::Literals::StringLiterals;
-using TextIconPair = QPair<QString, QIcon>;
 
 AttendeeComboBox::AttendeeComboBox(QWidget *parent)
     : QToolButton(parent)
@@ -35,7 +34,7 @@ AttendeeComboBox::AttendeeComboBox(QWidget *parent)
 
 void AttendeeComboBox::addItem(const QIcon &icon, const QString &text)
 {
-    mList.append(TextIconPair(text, icon));
+    mList.append(IconPair{.icon = icon, .name = text});
     if (mCurrentIndex == -1) {
         setCurrentIndex(0);
     }
@@ -71,8 +70,8 @@ void AttendeeComboBox::setCurrentIndex(int index)
     Q_ASSERT(index < mList.size());
     const int old = mCurrentIndex;
     mCurrentIndex = index;
-    setIcon(mList.at(index).second);
-    setToolTip(mList.at(index).first);
+    setIcon(mList.at(index).icon);
+    setToolTip(mList.at(index).name);
     if (old != index) {
         Q_EMIT itemChanged();
     }
@@ -80,7 +79,7 @@ void AttendeeComboBox::setCurrentIndex(int index)
 
 void AttendeeComboBox::slotActionTriggered()
 {
-    int index = qobject_cast<QAction *>(sender())->data().toInt();
+    int const index = qobject_cast<QAction *>(sender())->data().toInt();
     setCurrentIndex(index);
 }
 
@@ -230,7 +229,7 @@ void AttendeeLine::dataFromFields()
         return;
     }
 
-    KCalendarCore::Attendee oldAttendee(mData->attendee());
+    KCalendarCore::Attendee const oldAttendee(mData->attendee());
 
     QString email;
     QString name;
@@ -260,7 +259,7 @@ void AttendeeLine::fieldsFromData()
 
     mEdit->setText(mData->fullName());
     mRoleCombo->setCurrentIndex(mData->role());
-    AttendeeData::PartStat partStat = mData->status();
+    AttendeeData::PartStat const partStat = mData->status();
     if (partStat != AttendeeData::None) {
         mStateCombo->setCurrentIndex(partStat);
     } else {
@@ -320,7 +319,7 @@ void AttendeeLine::setCompletionMode(KCompletion::CompletionMode mode)
 
 void AttendeeLine::setData(const KPIM::MultiplyingLineData::Ptr &data)
 {
-    AttendeeData::Ptr attendee = qSharedPointerDynamicCast<AttendeeData>(data);
+    AttendeeData::Ptr const attendee = qSharedPointerDynamicCast<AttendeeData>(data);
     if (!attendee) {
         return;
     }
