@@ -135,7 +135,7 @@ int ConflictResolver::tryDate(QDateTime &tryFrom, QDateTime &tryTo)
 {
     int conflicts_count = 0;
     for (int i = 0; i < mFBModel->rowCount(); ++i) {
-        QModelIndex index = mFBModel->index(i);
+        QModelIndex const index = mFBModel->index(i);
         auto attendee = mFBModel->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalendarCore::Attendee>();
         if (!matchesRoleConstraint(attendee)) {
             continue;
@@ -191,7 +191,7 @@ bool ConflictResolver::findFreeSlot(const KCalendarCore::Period &dateTimeRange)
 
     // Make sure that we never suggest a date in the past, even if the
     // user originally scheduled the meeting to be in the past.
-    QDateTime now = QDateTime::currentDateTimeUtc();
+    QDateTime const now = QDateTime::currentDateTimeUtc();
     if (tryFrom < now) {
         // The slot to look for is at least partially in the past.
         const qint64 secs = tryFrom.secsTo(tryTo);
@@ -243,8 +243,6 @@ void ConflictResolver::findAllFreeSlots()
     //          So, the array would have a length of 672
     const int range = begin.secsTo(end) / mSlotResolutionSeconds;
     if (range <= 0) {
-        qCWarning(INCIDENCEEDITOR_LOG) << "free slot calculation: invalid range. range( " << begin.secsTo(end) << ") / mSlotResolutionSeconds("
-                                       << mSlotResolutionSeconds << ") = " << range;
         return;
     }
 
@@ -253,7 +251,7 @@ void ConflictResolver::findAllFreeSlots()
     // and which don't match the mandatory role constraint
     QList<KCalendarCore::FreeBusy::Ptr> filteredFBItems;
     for (int i = 0; i < mFBModel->rowCount(); ++i) {
-        QModelIndex index = mFBModel->index(i);
+        QModelIndex const index = mFBModel->index(i);
         auto attendee = mFBModel->data(index, CalendarSupport::FreeBusyItemModel::AttendeeRole).value<KCalendarCore::Attendee>();
         if (!matchesRoleConstraint(attendee)) {
             continue;
@@ -398,6 +396,7 @@ void ConflictResolver::findAllFreeSlots()
     if (free_found) {
         Q_EMIT freeSlotsAvailable(mAvailableSlots);
     }
+// NOLINTBEGIN(readability-avoid-unconditional-preprocessor-if)
 #if 0
     //DEBUG, dump the arrays. very helpful for debugging
     QTextStream dump(stdout);
@@ -425,6 +424,7 @@ void ConflictResolver::findAllFreeSlots()
     }
     dump << "\n";
 #endif
+    // NOLINTEND(readability-avoid-unconditional-preprocessor-if)
 }
 
 void ConflictResolver::calculateConflicts()
