@@ -5,6 +5,7 @@
  *
  */
 #include "resourceitem.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include <KLDAPCore/LdapServer>
 
@@ -25,7 +26,7 @@ ResourceItem::ResourceItem(const KLDAPCore::LdapDN &dn, const QStringList &attrs
 
         connect(&mLdapClient, &KLDAPCore::LdapClient::result, this, &ResourceItem::slotLDAPResult);
 
-        mAttrs << QStringLiteral("uniqueMember");
+        mAttrs << u"uniqueMember"_s;
         mLdapClient.setAttributes(attrs);
     } else {
         itemData.reserve(mAttrs.count());
@@ -51,8 +52,8 @@ int ResourceItem::childNumber() const
 {
     if (parentItem) {
         int i = 0;
-        for (const ResourceItem::Ptr &child : std::as_const(parentItem->childItems)) {
-            if (child == this) {
+        for (const ResourceItem::Ptr &item : std::as_const(parentItem->childItems)) {
+            if (item == this) {
                 return i;
             }
             i++;
@@ -74,8 +75,10 @@ QVariant ResourceItem::data(int column) const
 
 QVariant ResourceItem::data(const QString &column) const
 {
-    if (!mLdapObject.attributes()[column].isEmpty()) {
-        return QString::fromUtf8(mLdapObject.attributes()[column][0]);
+    const auto ldapAttributes = mLdapObject.attributes();
+    const auto &attribute = ldapAttributes.value(column);
+    if (!attribute.isEmpty()) {
+        return QString::fromUtf8(attribute[0]);
     }
     return {};
 }
@@ -121,7 +124,7 @@ const KLDAPCore::LdapObject &ResourceItem::ldapObject() const
 
 void ResourceItem::startSearch()
 {
-    mLdapClient.startQuery(QStringLiteral("objectclass=*"));
+    mLdapClient.startQuery(u"objectclass=*"_s);
 }
 
 void ResourceItem::setLdapObject(const KLDAPCore::LdapObject &obj)
@@ -138,9 +141,11 @@ void ResourceItem::slotLDAPResult(const KLDAPCore::LdapClient &client, const KLD
 {
     Q_UNUSED(client)
     mLdapObject = obj;
+    const auto ldapAttributes = mLdapObject.attributes();
     for (const QString &header : std::as_const(mAttrs)) {
-        if (!obj.attributes()[header].isEmpty()) {
-            itemData << QString::fromUtf8(obj.attributes()[header][0]);
+        const auto &attribute = ldapAttributes.value(header);
+        if (!attribute.isEmpty()) {
+            itemData << QString::fromUtf8(attribute[0]);
         } else {
             itemData << QString();
         }
